/// <reference types="node" />
import { IGateway } from './IGateway';
import { ILocation } from './ILocation';
import { IPackage } from './IPackage';
import { IThetaPhiRssi } from './IThetaPhiRssi';
import { IThetaPhiRssiLog } from './IThetaPhiRssiLog';
import { IBeaconGroup } from './IBeaconsGroup';
import { IStaticBeacon } from './IStaticBeacon';
export declare class Algorithm {
    constructor(gateways: IGateway[], beaconHeight: number);
    calcAoa(buff: ArrayBuffer): IThetaPhiRssi;
    calcAoaCircle(buff: ArrayBuffer): IThetaPhiRssi;
    calcAoaPlane(buff: ArrayBuffer): IThetaPhiRssi;
    calcAoaGa25(buff: ArrayBuffer): IThetaPhiRssi;
    calcAoaAsync(buff: ArrayBuffer): Promise<IThetaPhiRssi>;
    calcAoaWithLog(buff: ArrayBuffer): IThetaPhiRssiLog;
    locate(package: IPackage): ILocation[];
    setParams(params: string): void;
    addZone(id: string, mapId: string, points: number[][]): void;
    setBeaconParams(mac: string, beaconHeight: number, params: string): void;
    setSmoothLevel(level: number): void;
    calcRssi(buff: ArrayBuffer): number;
    setAntennaPos(aps: number[][]): void;
    addBeaconsGroup(bg: IBeaconGroup): void;
    locate_beacons_group(beacon_mac: string): ILocation;
    addStaticBeacon(sb: IStaticBeacon): void;
    updateStaticBeaconScanRes(sMac: string, static_beacon_mac: string, rx_rssi: number): void;
    setBeaconHeight(mac: string, bh: number): void;
    getNearestGateway(location: ILocation): string;
    setGsensorParams(gsensor_mode: number, gsensor_change_ratio: number, gsensor_switch_time_move2static: number, gsensor_switch_time_static2move: number): void;
    setJumpParams(jump_mode: number, jump_distance: number): void;
    setSmoothParams(smooth_mode: number): void;
    setSignalFilterParams(signal_filter_mode: number): void;
    setMapSwitchParams(map_switch_mode: number): void;
}
export declare class AoaRssiCombiner {
    constructor(gateways: IGateway[], beaconHeight: number);
    locateCombiner(sMac: string, location: ILocation): ILocation;
    addZone(id: string, mapId: string, points: number[][]): void;
}
export declare class CalcFuncs {
    constructor();
    calcRssiFromAoa(buff: Buffer): number;
    calcRssiFromAoaGa25(buff: Buffer): number;
    calcRssiFromAoaPlane(buff: Buffer): number;
    calcRssiFromRssi(buff: Buffer): number;
}
